import asyncio
import logging
import os
import schedule
import time
import requests
from telegram import Bot
from dotenv import load_dotenv
from pathlib import Path

# Configure logging
logging.basicConfig(
    level=logging.INFO,
    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
)
logger = logging.getLogger(__name__)

# Load environment variables from .env file
env_path = Path(__file__).resolve().parent.parent.parent / '.env'
if env_path.exists():
    load_dotenv(env_path)
else:
    logger.warning(f"No .env file found at {env_path}. Please create one based on .env.example")

# Configuration
TELEGRAM_TOKEN = os.getenv('TELEGRAM_TOKEN')
TELEGRAM_CHANNEL = os.getenv('TELEGRAM_CHANNEL')
API_URL = 'https://eci.ec.europa.eu/045/public/api/report/progression'

async def send_to_telegram(message: str):
    """Send a message to the configured Telegram channel."""
    if not TELEGRAM_TOKEN or not TELEGRAM_CHANNEL:
        logger.error("Telegram configuration missing. Set TELEGRAM_TOKEN and TELEGRAM_CHANNEL environment variables.")
        return
    
    bot = Bot(token=TELEGRAM_TOKEN)
    try:
        await bot.send_message(chat_id=TELEGRAM_CHANNEL, text=message)
        logger.info("Message sent successfully")
    except Exception as e:
        logger.error(f"Failed to send message: {e}")

def get_signature_data():
    """Get the signature count and goal from the API endpoint."""
    try:
        response = requests.get(API_URL)
        response.raise_for_status()
        data = response.json()
        return {
            'count': data['signatureCount'],
            'goal': data['goal']
        }
    except Exception as e:
        logger.error(f"Failed to get signature data: {e}")
        return None

def job():
    """Main job that gets the signature data and sends it to Telegram."""
    data = get_signature_data()
    if data:
        percentage = (data['count'] / data['goal']) * 100
        message = f"📊 Signature Progress:\n"
        message += f"Current: {data['count']:,}\n"
        message += f"Goal: {data['goal']:,}\n"
        message += f"Progress: {percentage:.1f}%"
        asyncio.run(send_to_telegram(message))

def main():
    """Main function that schedules and runs the scraping job."""
    logger.info("Starting SKG Watcher...")
    
    # Run job immediately once
    job()
    
    # Schedule job to run every 15 minutes
    schedule.every(15).minutes.do(job)
    
    while True:
        schedule.run_pending()
        time.sleep(1)

if __name__ == "__main__":
    main()
